@@ -1,6 +1,6 @@
 package Bio::MLST::CDC::Convert;
 # ABSTRACT: Take in a fasta file of emmST sequences and convert it into an MLST format
-
+$Bio::MLST::CDC::Convert::VERSION = '2.0.1510612';
 
 
 use Moose;
@@ -84,7 +84,7 @@ sub _create_profile
   my ($self,$sequence_names) = @_;
   open(my $profile, '+>', $self->_output_profile_filename ) or die 'Couldnt open output profile file';
 
-  my $csv_out = Text::CSV->new({binary=>1, sep_char=>"\t", eol=>"\n"});
+  my $csv_out = Text::CSV->new({binary=>1, always_quote=>1, sep_char=>"\t", eol=>"\n"});
   $csv_out->print($profile,['ST',$self->gene_name]);
   
   
@@ -110,7 +110,7 @@ Bio::MLST::CDC::Convert - Take in a fasta file of emmST sequences and convert it
 
 =head1 VERSION
 
-version 1.150910
+version 2.0.1510612
 
 =head1 SYNOPSIS
 
