@@ -1,6 +1,6 @@
 package Bio::MLST::Check;
 # ABSTRACT: Multilocus sequence type checking using blast
-
+$Bio::MLST::Check::VERSION = '2.0.1510612';
 
 use Moose;
 use Parallel::ForkManager;
@@ -45,12 +45,13 @@ sub _generate_spreadsheet_rows
       my ($pid, $exit_code, $ident, $exit_signal, $core_dump, $data_structure_reference) = @_;
       # retrieve data structure from child
       if (defined($data_structure_reference)) {  # children are not forced to send anything
-        push(@{$self->_spreadsheet_header}, $data_structure_reference->[0]);
-        push(@{$self->_spreadsheet_allele_numbers_rows}, $data_structure_reference->[1]);
-        push(@{$self->_spreadsheet_genomic_rows}, $data_structure_reference->[2]);
+        my ($header_row, $allele_numbers_row, $genomic_row, $concat_name, $concat_sequence) = @{$data_structure_reference};
+        push(@{$self->_spreadsheet_header}, $header_row);
+        push(@{$self->_spreadsheet_allele_numbers_rows}, $allele_numbers_row);
+        push(@{$self->_spreadsheet_genomic_rows}, $genomic_row);
         
-        push(@{$self->_concat_names}, $data_structure_reference->[3]);
-        push(@{$self->_concat_sequences}, $data_structure_reference->[4]);
+        push(@{$self->_concat_names}, $concat_name);
+        push(@{$self->_concat_sequences}, $concat_sequence);
 
       } else {  # problems occuring during storage or retrieval will throw a warning
         print qq|No message received from child process $pid!\n|;
@@ -175,7 +176,7 @@ Bio::MLST::Check - Multilocus sequence type checking using blast
 
 =head1 VERSION
 
-version 1.150910
+version 2.0.1510612
 
 =head1 SYNOPSIS
 
