@@ -1,6 +1,6 @@
 package Bio::MLST::Download::Downloadable;
 # ABSTRACT: Moose Role to download everything data
-
+$Bio::MLST::Download::Downloadable::VERSION = '2.0.1510612';
 
 
 use Moose::Role;
@@ -20,7 +20,8 @@ sub _download_file
   }
   else
   {
-    getstore($filename, join('/',($destination_directory,$self->_get_filename_from_url($filename))));
+    my $status = getstore($filename, join('/',($destination_directory,$self->_get_filename_from_url($filename))));
+    die "Something went wrong, got a $status status code" if is_error($status);
   }
   1;
 }
@@ -70,7 +71,7 @@ Bio::MLST::Download::Downloadable - Moose Role to download everything data
 
 =head1 VERSION
 
-version 1.150910
+version 2.0.1510612
 
 =head1 SYNOPSIS
 
