@@ -1,8 +1,9 @@
 package Bio::MLST::SequenceType;
 # ABSTRACT: Take in a list of matched alleles and look up the sequence type from the profile.
-
+$Bio::MLST::SequenceType::VERSION = '2.0.1510612';
 
 use Data::Dumper;
+use Text::CSV;
 
 use Moose;
 use Bio::MLST::Types;
@@ -27,17 +28,11 @@ sub sequence_type_or_nearest
 sub _build__profiles
 {
   my($self) = @_;
-  my @profile ;
   open(my $fh, $self->profiles_filename) or die "Couldnt open profile: ".$self->profiles_filename."\n";
-  while(<$fh>)
-  {
-    chomp;
-    my $line = $_;
-    my @profile_row = split("\t",$line);
-    push(@profile, \@profile_row);
-  }
+  my $csv_in = Text::CSV->new({sep_char=>"\t"});
+  my $profile = $csv_in->getline_all($fh);
   
-  return \@profile;
+  return $profile;
 }
 
 sub _build_allele_to_number
@@ -138,7 +133,7 @@ Bio::MLST::SequenceType - Take in a list of matched alleles and look up the sequ
 
 =head1 VERSION
 
-version 1.150910
+version 2.0.1510612
 
 =head1 SYNOPSIS
 
